@@ -16,9 +16,9 @@ class Enums:
     COMMUNITY = 'Comunidad'
     STANDARD = 'Estándar'
     LIST_TYPE_INVITE_ROLE = [COMMUNITY, STANDARD]
-    JOB_OFFER = 'Oferta de trabajo'
+    TYPE_CONTRACT = 'Tipo de contrato'
     DOCUMENT = 'Documento'
-    LIST_TYPE_CATEGORIES = [COMMUNITY, JOB_OFFER, DOCUMENT]
+    LIST_TYPE_CATEGORIES = [COMMUNITY, TYPE_CONTRACT, DOCUMENT]
     CONTENT_IMAGE = 'image/png'
     CONTENT_VIDEO = 'video/mp4'
     CONTENT_FILE = 'application/pdf'
